@@ -265,7 +265,11 @@ def general_forecast_run_all_batches(
         forecast_one_batch = callable_function_for_on_batch(**callbacks_args)
 
         if i == 0:
-            logger.debug(f"First forecasts are {forecast_one_batch}")
+            logger.debug(
+                f'First forecasts are '
+                f'{forecast_one_batch[["target_datetime_utc","forecast_gsp_pv_outturn_mw"]]} '
+                f'{forecast_one_batch}'
+            )
 
         forecasts.append(forecast_one_batch)
 
